@@ -34,8 +34,7 @@ $GLOBALS['LSconfig'] = array(
     array (
       'name' => 'LSexample',
       'ldap_config'=> array(
-            'host'     => '127.0.0.1',
-            'host'     => 'ldapsaisie.easter-eggs.org',
+            'host'     => 'ldapsaisie.easter-eggs.com',
             'port'     => 389,
             'version'  => 3,
             'starttls' => false,
@@ -54,7 +53,7 @@ $GLOBALS['LSconfig'] = array(
       'LSprofiles' => array (
         'admin' => array (
           'o=ls' => array (
-            'uid=admin,ou=people,o=ls' => NULL
+            'uid=eeggs,ou=people,o=ls' => NULL
           ),
           'ou=people,o=ls' => array (
             'cn=adminldap,ou=groups,o=ls' => array (
@@ -183,7 +182,7 @@ define('LS_IMAGES_DIR', 'images');
 define('LS_CSS_DIR', 'css');
 
 //Debug
-define('LSdebug',true);
+define('LSdebug',false);
 
 // Logs
 $GLOBALS['LSlog']['filename'] = 'tmp/LS.log';
